@@ -119,6 +119,7 @@ class Language(enum.Enum):
     so = ("Somali")
     es = ("Spanish")
     es_mx = ("Spanish (Mexico)")
+    rn = ("Rundi")
     sa = ("Sanskrit")
     su = ("Sundanese")
     sw = ("Swahili")
@@ -128,10 +129,12 @@ class Language(enum.Enum):
     tt = ("Tatar")
     te = ("Telugu")
     th = ("Thai")
+    tn = ("Setswana")
     ti = ("Tigrinya")
     tr = ("Turkish")
     ts = ("Tsonga")
     tk = ("Turkmen")
+    tok = ("Toki Pona")
     uk = ("Ukrainian")
     ur = ("Urdu")
     ug = ("Uyghur")
